@@ -36,12 +36,12 @@ class BananaMonitoringConfig(BaseConfig):
     alert_config: Optional[AlertConfig] = None
     index_to_category: Optional[Dict[int, str]] = field(
         default_factory=lambda: {
-            1: "freshripe",
-            2: "freshunripe",
-            3: "overripe",
-            4: "ripe",
-            5: "rotten",
-            6: "unripe"
+            0: "overripe",
+            1: "rotten",
+            2: "ripe",
+            3: "unripe",
+            4: "freshripe",
+            5: "freshunripe"
         }
     )
 
