@@ -26,10 +26,10 @@ class TrafficSignMonitoringConfig(BaseConfig):
     smoothing_window_size: int = 20
     smoothing_cooldown_frames: int = 5
     smoothing_confidence_range_factor: float = 0.5
-    confidence_threshold: float = 0.6
+    confidence_threshold: float = 0.5
     sign_categories: List[str] = field(
         default_factory=lambda: [
-            'Red Light', 'Speed Limit 10', 'Speed Limit 100', 'Speed Limit 110',
+            'Green Light','Red Light', 'Speed Limit 10', 'Speed Limit 100', 'Speed Limit 110',
             'Speed Limit 120', 'Speed Limit 20', 'Speed Limit 30', 'Speed Limit 40',
             'Speed Limit 50', 'Speed Limit 60', 'Speed Limit 70', 'Speed Limit 80',
             'Speed Limit 90', 'Stop'
@@ -37,7 +37,8 @@ class TrafficSignMonitoringConfig(BaseConfig):
     )
     target_sign_categories: List[str] = field(
         default_factory=lambda: [
-            'Red Light', 'Speed Limit 10', 'Speed Limit 100', 'Speed Limit 110',
+
+            'Green Light','Red Light', 'Speed Limit 10', 'Speed Limit 100', 'Speed Limit 110',
             'Speed Limit 120', 'Speed Limit 20', 'Speed Limit 30', 'Speed Limit 40',
             'Speed Limit 50', 'Speed Limit 60', 'Speed Limit 70', 'Speed Limit 80',
             'Speed Limit 90', 'Stop'
@@ -46,6 +47,7 @@ class TrafficSignMonitoringConfig(BaseConfig):
     alert_config: Optional[AlertConfig] = None
     index_to_category: Optional[Dict[int, str]] = field(
         default_factory=lambda: {
+            -1: "Green Light",
             0: "Red Light",
             1: "Speed Limit 10",
             2: "Speed Limit 100",
@@ -196,7 +198,7 @@ class TrafficSignMonitoringUseCase(BaseProcessor):
         super().__init__("traffic_sign_monitoring")
         self.category = "traffic"
         self.sign_categories = [
-            'Red Light', 'Speed Limit 10', 'Speed Limit 100', 'Speed Limit 110',
+            'Green Light','Red Light', 'Speed Limit 10', 'Speed Limit 100', 'Speed Limit 110',
             'Speed Limit 120', 'Speed Limit 20', 'Speed Limit 30', 'Speed Limit 40',
             'Speed Limit 50', 'Speed Limit 60', 'Speed Limit 70', 'Speed Limit 80',
             'Speed Limit 90', 'Stop'
@@ -502,6 +504,7 @@ class TrafficSignMonitoringUseCase(BaseProcessor):
         }
 
     CATEGORY_DISPLAY = {
+        "Green Light" : "Green Light",
         "Red Light": "Red Light",
         "Speed Limit 10": "Speed Limit 10",
         "Speed Limit 100": "Speed Limit 100",
